//! Generated low-level bindings to the SWI-Prolog fli.
#![doc(html_root_url = "https://terminusdb-labs.github.io/swipl-rs/swipl_fli/")]
#![allow(non_upper_case_globals)]
#![allow(non_camel_case_types)]
#![allow(non_snake_case)]
// TODO any function that uses u128 should be excluded
#![allow(improper_ctypes)]

include!(concat!(env!("OUT_DIR"), "/bindings.rs"));
